diff --git a/Jellyfin.Api/Controllers/SessionController.cs b/Jellyfin.Api/Controllers/SessionController.cs
index 2ed7019e5..68cec1415 100644
--- a/Jellyfin.Api/Controllers/SessionController.cs
+++ b/Jellyfin.Api/Controllers/SessionController.cs
@@ -5,6 +5,7 @@ using System.Linq;
using System.Threading;
using Jellyfin.Api.Constants;
using Jellyfin.Api.Helpers;
+using Jellyfin.Api.ModelBinders;
using Jellyfin.Data.Enums;
using MediaBrowser.Controller.Devices;
using MediaBrowser.Controller.Library;
@@ -366,7 +367,7 @@ namespace Jellyfin.Api.Controllers
///
/// The session id.
/// A list of playable media types, comma delimited. Audio, Video, Book, Photo.
/// A list of supported remote control commands.
/// Determines whether media can be played remotely..
/// Determines whether sync is supported.
/// Determines whether the device supports a unique identifier.
@@ -378,7 +379,7 @@ namespace Jellyfin.Api.Controllers
public ActionResult PostCapabilities(
[FromQuery] string? id,
[FromQuery] string? playableMediaTypes,
- [FromQuery] GeneralCommandType[] supportedCommands,
+ [FromQuery][ModelBinder(typeof(CommaDelimitedArrayModelBinder))] GeneralCommandType[] supportedCommands,
[FromQuery] bool supportsMediaControl = false,
[FromQuery] bool supportsSync = false,
[FromQuery] bool supportsPersistentIdentifier = true)
@@ -366,7 +367,7 @@ namespace Jellyfin.Api.Controllers
/// The session id.
/// A list of playable media types, comma delimited. Audio, Video, Book, Photo.
- /// A list of supported remote control commands.
+ /// A list of supported remote control commands, comma delimited.
/// Determines whether media can be played remotely..
/// Determines whether sync is supported.